@@ -253,7 +253,9 @@ int feh_is_image(feh_file * file)
 	if (!fh) {
 		return 0;
 	}
-	if (fread(buf, 1, 16, fh) != 16) {
+	// Files smaller than buf will be padded with zeroes
+	memset(buf, 0, sizeof(buf));
+	if (fread(buf, 1, 16, fh) <= 0) {
 		fclose(fh);
 		return 0;
 	}
@@ -312,6 +314,11 @@ int feh_is_image(feh_file * file)
 		// imlib2 releases do not support heic/heif images as of 2021-01.
 		return 1;
 	}
+	if ((buf[0] == 0xff && buf[1] == 0x0a) || !memcmp(buf, "\x00\x00\x00\x0cJXL \x0d\x0a\x87\x0a", 12)) {
+		// JXL - note that this is only supported in imlib2-jxl. Ordinary
+		// imlib2 releases do not support JXL images as of 2021-06.
+		return 1;
+	}
 	buf[15] = 0;
 	if (strstr((char *)buf, "XPM")) {
 		// XPM
@@ -455,8 +462,9 @@ int feh_load_image(Imlib_Image * im, feh_file * file)
 	if (file->ed) {
 		ExifByteOrder byteOrder = exif_data_get_byte_order(file->ed);
 		ExifEntry *exifEntry = exif_data_get_entry(file->ed, EXIF_TAG_ORIENTATION);
-		if (exifEntry && opt.auto_rotate)
+		if (exifEntry && opt.auto_rotate) {
 			orientation = exif_get_short(exifEntry->data, byteOrder);
+		}
 	}
 
 	if (orientation == 2)
@@ -862,15 +870,32 @@ static char *feh_http_load_image(char *url)
 	}
 
 	basename = strrchr(url, '/') + 1;
-	tmpname = feh_unique_filename(path, basename);
 
-	if (strlen(tmpname) > (NAME_MAX-6))
-		tmpname[NAME_MAX-7] = '\0';
+#ifdef HAVE_MKSTEMPS
+	tmpname = estrjoin("_", "feh_curl_XXXXXX", basename, NULL);
 
-	sfn = estrjoin("_", tmpname, "XXXXXX", NULL);
+	if (strlen(tmpname) > NAME_MAX) {
+		tmpname[NAME_MAX] = '\0';
+	}
+#else
+	if (strlen(basename) > NAME_MAX-7) {
+		tmpname = estrdup("feh_curl_XXXXXX");
+	} else {
+		tmpname = estrjoin("_", "feh_curl", basename, "XXXXXX", NULL);
+	}
+#endif
+
+	sfn = estrjoin("", path, tmpname, NULL);
 	free(tmpname);
 
+	D(("sfn is %s\n", sfn))
+
+#ifdef HAVE_MKSTEMPS
+	fd = mkstemps(sfn, strlen(basename) + 1);
+#else
 	fd = mkstemp(sfn);
+#endif
+
 	if (fd != -1) {
 		sfp = fdopen(fd, "w+");
 		if (sfp != NULL) {
@@ -879,8 +904,8 @@ static char *feh_http_load_image(char *url)
 #endif
 			/*
 			 * Do not allow requests to take longer than 30 minutes.
-			 * This should be sufficiently high to accomodate use cases with
-			 * unusually high latencies, while at the sime time avoiding
+			 * This should be sufficiently high to accommodate use cases with
+			 * unusually high latencies, while at the same time avoiding
 			 * feh hanging indefinitely in unattended slideshows.
 			 */
 			curl_easy_setopt(curl, CURLOPT_TIMEOUT, 1800);
@@ -929,7 +954,11 @@ static char *feh_http_load_image(char *url)
 			close(fd);
 		}
 	} else {
+#ifdef HAVE_MKSTEMPS
+		weprintf("open url: mkstemps failed:");
+#else
 		weprintf("open url: mkstemp failed:");
+#endif
 		free(sfn);
 	}
 	curl_easy_cleanup(curl);
@@ -1159,7 +1188,7 @@ void feh_draw_exif(winwidget w)
 
 	if (buffer[0] == '\0')
 	{
-		snprintf(buffer, EXIF_MAX_DATA, "%s", estrdup("Failed to run exif command"));
+		snprintf(buffer, EXIF_MAX_DATA, "%s", "Failed to run exif command");
 		gib_imlib_get_text_size(fn, buffer, NULL, &width, &height, IMLIB_TEXT_TO_RIGHT);
 		info_buf[no_lines] = estrdup(buffer);
 		no_lines++;
@@ -1171,29 +1200,28 @@ void feh_draw_exif(winwidget w)
 		{
 			/* max 128 lines */
 			pos2 = 0;
-			while ( pos2 < 256 ) /* max 256 chars per line */
+			while ( pos2 < 255 ) /* max 255 chars + 1 null byte per line */
 			{
 				if ( (buffer[pos] != '\n')
 				      && (buffer[pos] != '\0') )
 				{
-			    info_line[pos2] = buffer[pos];
-			  }
-			  else if ( buffer[pos] == '\0' )
-			  {
-			    pos = EXIF_MAX_DATA; /* all data seen */
-			    info_line[pos2] = '\0';
+					info_line[pos2] = buffer[pos];
+				}
+				else if ( buffer[pos] == '\0' )
+				{
+					pos = EXIF_MAX_DATA; /* all data seen */
+					break;
+				}
+				else
+				{
+					pos++; /* line finished, continue with next line*/
+					break;
 				}
-			  else
-			  {
-			  	info_line[pos2] = '\0'; /* line finished, continue with next line*/
 
-			    pos++;
-			    break;
-			  }
-
-			   pos++;
-			   pos2++;
+				pos++;
+				pos2++;
 			}
+			info_line[pos2] = '\0';
 
 			gib_imlib_get_text_size(fn, info_line, NULL, &line_width,
                               &line_height, IMLIB_TEXT_TO_RIGHT);
