@@ -104,8 +104,13 @@ winwidget winwidget_create_from_image(Imlib_Image im, char type)
 	ret->w = ret->im_w = gib_imlib_image_get_width(ret->im);
 	ret->h = ret->im_h = gib_imlib_image_get_height(ret->im);
 
-	if (opt.full_screen && (type != WIN_TYPE_THUMBNAIL))
+	if (opt.full_screen && (type != WIN_TYPE_THUMBNAIL)) {
 		ret->full_screen = True;
+	} else if (opt.default_zoom) {
+		ret->zoom = 0.01 * opt.default_zoom;
+		ret->w *= ret->zoom;
+		ret->h *= ret->zoom;
+	}
 	winwidget_create_window(ret, ret->w, ret->h);
 	winwidget_render_image(ret, 1, 0);
 
@@ -133,8 +138,13 @@ winwidget winwidget_create_from_file(gib_list * list, char type)
 		ret->w = ret->im_w = gib_imlib_image_get_width(ret->im);
 		ret->h = ret->im_h = gib_imlib_image_get_height(ret->im);
 		D(("image is %dx%d pixels, format %s\n", ret->w, ret->h, gib_imlib_image_format(ret->im)));
-		if (opt.full_screen)
+		if (opt.full_screen) {
 			ret->full_screen = True;
+		} else if (opt.default_zoom) {
+			ret->zoom = 0.01 * opt.default_zoom;
+			ret->w *= ret->zoom;
+			ret->h *= ret->zoom;
+		}
 		winwidget_create_window(ret, ret->w, ret->h);
 		winwidget_render_image(ret, 1, 0);
 	}
@@ -144,6 +154,7 @@ winwidget winwidget_create_from_file(gib_list * list, char type)
 
 void winwidget_create_window(winwidget ret, int w, int h)
 {
+	XWindowAttributes window_attr;
 	XSetWindowAttributes attr;
 	XEvent ev;
 	XClassHint *xch;
@@ -250,11 +261,31 @@ void winwidget_create_window(winwidget ret, int w, int h)
 		}
 	}
 
-	ret->win =
-	    XCreateWindow(disp, DefaultRootWindow(disp), x, y, w, h, 0,
-			  depth, InputOutput, vis,
-			  CWOverrideRedirect | CWSaveUnder | CWBackingStore
-			  | CWColormap | CWBackPixel | CWBorderPixel | CWEventMask, &attr);
+	if (opt.x11_windowid == 0) {
+		ret->win =
+		  XCreateWindow(disp, DefaultRootWindow(disp), x, y, w, h, 0,
+		                depth, InputOutput, vis,
+		                CWOverrideRedirect | CWSaveUnder | CWBackingStore
+		                | CWColormap | CWBackPixel | CWBorderPixel | CWEventMask,
+		                &attr);
+	} else {
+		/* x11_windowid is a pointer to the window */
+		ret->win = (Window) opt.x11_windowid;
+
+		/* set our attributes on the window */
+		XChangeWindowAttributes(disp, ret->win,
+                            CWOverrideRedirect | CWSaveUnder | CWBackingStore
+                            | CWColormap | CWBackPixel | CWBorderPixel
+                            | CWEventMask, &attr);
+
+		/* determine the size and visibility of the window */
+		XGetWindowAttributes(disp, ret->win, &window_attr);
+		ret->visible = (window_attr.map_state == IsViewable);
+		ret->x = window_attr.x;
+		ret->y = window_attr.y;
+		ret->w = window_attr.width;
+		ret->h = window_attr.height;
+	}
 
 	if (mwmhints.flags) {
 		XChangeProperty(disp, ret->win, prop, prop, 32,
@@ -433,7 +464,12 @@ void winwidget_render_image(winwidget winwid, int resize, int force_alias)
 	int antialias = 0;
 
 	if (!winwid->full_screen && resize) {
-		winwidget_resize(winwid, winwid->im_w, winwid->im_h, 0);
+		if (opt.default_zoom) {
+			winwid->zoom = 0.01 * opt.default_zoom;
+			winwidget_resize(winwid, winwid->im_w * winwid->zoom, winwid->im_h * winwid->zoom, 0);
+		} else {
+			winwidget_resize(winwid, winwid->im_w, winwid->im_h, 0);
+		}
 		winwidget_reset_image(winwid);
 	}
 
@@ -742,7 +778,7 @@ void feh_event_handle_inotify(void)
         for (int j = 0; j < window_num; j++) {
             if(windows[j]->inotify_wd == event->wd) {
                 if (event->mask & IN_IGNORED) {
-                    D(("inotify watch was implicitely removed\n"));
+                    D(("inotify watch was implicitly removed\n"));
                     windows[j]->inotify_wd = -1;
                 } else if (event->mask & (IN_CLOSE_WRITE | IN_MOVED_TO)) {
                     if (strcmp(event->name, FEH_FILE(windows[j]->file->data)->name) == 0) {
